@@ -21,7 +21,7 @@ def solve(sought,
           adjacent=None,
           opposite=None,
           hypotenuse=None,
-          solve=False):
+          solve=True):
 
     """
     Solve for ``sought``.
@@ -29,9 +29,9 @@ def solve(sought,
     ``sought`` should be a string with the following possible values:
     ``adjacent``, ``opposite``, ``hypotenuse``.
 
-    If ``solve`` is left at its default value of ``False``, an equation is
-    returned as string that would provide the sought value. If it is set to
-    ``True``, the value of the sought side is returned.
+    If ``solve`` is left at its default value of ``True``, the value of the
+    sought side is returned. If it is set to ``False``, an equation is returned
+    as string that would provide the sought value.
 
     Angles are expected and returned in degrees.
     """
